# PrinterProfileRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**octoprint_device** | **int** |  | 
**axes_e_inverted** | **bool** |  | [optional] 
**axes_e_speed** | **int** |  | [optional] 
**axes_x_speed** | **int** |  | [optional] 
**axes_x_inverted** | **bool** |  | [optional] 
**axes_y_inverted** | **bool** |  | [optional] 
**axes_y_speed** | **int** |  | [optional] 
**axes_z_inverted** | **bool** |  | [optional] 
**axes_z_speed** | **int** |  | [optional] 
**extruder_count** | **int** |  | [optional] 
**extruder_nozzle_diameter** | **float** |  | [optional] 
**extruder_shared_nozzle** | **bool** |  | [optional] 
**heated_bed** | **bool** |  | [optional] 
**heated_chamber** | **bool** |  | [optional] 
**model** | **str** |  | [optional] 
**name** | **str** |  | 
**octoprint_key** | **str** |  | 
**volume_custom_box** | **dict(str, object)** |  | [optional] 
**volume_depth** | **float** |  | [optional] 
**volume_formfactor** | **str** |  | [optional] 
**volume_height** | **float** |  | [optional] 
**volume_origin** | **str** |  | [optional] 
**volume_width** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


